from setuptools import setup, find_packages

setup(
    name = 'cetchelloworld',
    version = '0.0.7',
    package = find_packages(),
    install_requires = [],
    include_package_data=True,
    packages=["cetchelloworld"]
)